# [silver](https://www.presslabs.com/code/silver/)

[![Build Status](https://travis-ci.org/silverapp/silver.svg?branch=master)](https://travis-ci.org/silverapp/silver)
[![Build Status](https://drone.presslabs.net/api/badges/silverapp/silver/status.svg?branch=master)](https://drone.presslabs.net/silverapp/silver)
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fsilverapp%2Fsilver.svg?type=shield)](https://app.fossa.io/projects/git%2Bgithub.com%2Fsilverapp%2Fsilver?ref=badge_shield)

**A Django automated billing system with a REST API.**

Silver was developed by the awesome engineering team at
[Presslabs](https://www.presslabs.com/), a Managed WordPress Hosting
provider.

For the complete installation and configuration guide, check the [Silver Docs](https://www.presslabs.com/code/silver/).

For more open-source projects, check [Presslabs Code](https://www.presslabs.com/code/).
